<?xml version="1.0" ?><!DOCTYPE TS><TS language="sr" version="2.1">
	<context>
		<name>policy</name>
		<message>
			<location filename="com.deepin.pkexec.deepin-diskmanager!message" line="0"/>
			<source>Authentication is required to read disk information</source>
			<translation>Идентификација је неопходна за читање података о диску</translation>
		</message>
		<message>
			<location filename="com.deepin.pkexec.deepin-diskmanager!description" line="0"/>
			<source>Run Disk Manager Need Authentication</source>
			<translation>Run Disk Manager Need Authentication</translation>
		</message>
	</context>
</TS>